ContentPane DOH test

## dijit/layout/ContentPane DOH test

### Test designed to run on localhost (minimize impact from network latency)

#### This should NOT be parsed automatically

If this has a different background and a red border, the page parsed when it shouldn't

### Testing ContentPane

Even though the entire page isn't scanned for widgets, any sub widgets of a ContentPane will be created when a ContentPane is created
This should have a backgroundcolor and a border
hello world